@@ -1,6 +1,4 @@
 from .assignment import Assignment
-from .fulltext import Patent
-from .fulltext import PublishedApplication
 from .peds import USApplication
 from .ptab import PtabDecision
 from .ptab import PtabDocument
@@ -8,8 +6,6 @@ from .ptab import PtabProceeding
 
 __all__ = [
     "Assignment",
-    "Patent",
-    "PublishedApplication",
     "USApplication",
     "PtabDecision",
     "PtabDocument",
