@@ -1,13 +1,16 @@
 import datetime
 from dataclasses import dataclass
 from dataclasses import field
+from fileinput import filename
 from typing import *
 
 from patent_client.util import Model
-from patent_client.util.base.collections import ListManager
+from yankee.data import ListCollection
 
 from ...util.base.related import get_model
-
+from patent_client import session
+from pathlib import Path
+import re
 
 @dataclass
 class AdditionalRespondent(Model):
@@ -94,32 +97,33 @@ class PtabProceeding(Model):
     second_respondent_pub_number: str = None
     second_respondent_publication_date: "datetime.date" = None
 
-    additional_respondents: "ListManager[str]" = field(default_factory=list)
+    additional_respondents: "ListCollection[str]" = field(default_factory=list)
 
     def __repr__(self):
         return f"PtabProceeding(subproceeding_type_category='{self.subproceeding_type_category}', proceeding_number='{self.proceeding_number}', proceeding_status_category='{self.proceeding_status_category}', proceeding_type_category='{self.proceeding_type_category}', respondent_party_name='{self.respondent_party_name}')"
 
     @property
-    def documents(self) -> "ListManager[patent_client.uspto.ptab.model.PtabDocument]":
+    def documents(self) -> "ListCollection[patent_client.uspto.ptab.model.PtabDocument]":
         """Documents associated with the Proceeding"""
         return get_model("patent_client.uspto.ptab.model.PtabDocument").objects.filter(
             proceeding_number=self.proceeding_number
         )
 
     @property
-    def decisions(self) -> "ListManager[patent_client.uspto.ptab.model.PtabDecision]":
+    def decisions(self) -> "ListCollection[patent_client.uspto.ptab.model.PtabDecision]":
         """Decisions associated with the Proceeding"""
         return get_model("patent_client.uspto.ptab.model.PtabDecision").objects.filter(
             proceeding_number=self.proceeding_number
         )
 
     @property
-    def us_application(self) -> "ListManager[patent_client.uspto.peds.model.USApplication]":
+    def us_application(self) -> "ListCollection[patent_client.uspto.peds.model.USApplication]":
         """The US Application provided by PEDS associated with the Proceeding"""
         return get_model("patent_client.uspto.peds.model.USApplication").objects.get(
             patent_number=self.respondent_patent_number
         )
 
+fname_re = re.compile(r"[<>:\"/\|?*]")
 
 @dataclass
 class PtabDocument(Model):
@@ -141,17 +145,31 @@ class PtabDocument(Model):
             proceeding_number=self.proceeding_number
         )
 
+    def download(self, path="."):
+        name, ext = self.document_name.rsplit(".", 1)
+        name = name[:100] + "." + ext
+        filename = f"[{str(self.document_number).rjust(4, '0')}] {self.document_filing_date.isoformat()} - {name}"
+        filename = filename.encode(encoding="ascii", errors="ignore").decode("ascii")
+        filename = fname_re.sub("", filename)
+        out_path = Path(path) / filename
+        with session.get(f"https://developer.uspto.gov/ptab-api/documents/{self.document_identifier}/download", verify=False) as r:
+            r.raise_for_status()
+            with out_path.open("wb") as f:
+                for chunk in r.iter_content(chunk_size=8192):
+                    f.write(chunk)
+    
+
 
 @dataclass
 class PtabDecision(Model):
     __manager__ = "patent_client.uspto.ptab.manager.PtabDecisionManager"
     proceeding_number: str
-    board_rulings: "List[str]"
-    decision_type_category: str
-    document_identifier: str
-    document_name: str
-    identifier: str
-    subdecision_type_category: str
+    board_rulings: "List[str]" = field(default_factory=ListCollection)
+    decision_type_category: str = None
+    document_identifier: str = None
+    document_name: str = None
+    identifier: str = None
+    subdecision_type_category: str = None
     issue_type: "Optional[str]" = None
     object_uu_id: "Optional[str]" = None
     petitioner_technology_center_number: "Optional[str]" = None
